HealthDataSyncResult class final

Result of a synchronization operation containing changes since the last sync.

Annotations

Constructors

HealthDataSyncResult.internal({required List<HealthRecord> upsertedRecords, required List<HealthRecordId> deletedRecordIds, required bool hasMore, required HealthDataSyncToken? nextSyncToken})
Creates a HealthDataSyncResult instance.
factory

Properties

deletedRecordIds List<HealthRecordId>
IDs of records deleted since the last sync.
final
hashCode int
The hash code for this object.
no setteroverride
hasMore bool
Whether more changes are available in the current sync snapshot.
final
nextSyncToken HealthDataSyncToken?
Sync token for the next synchronization request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upsertedRecords List<HealthRecord>
Records added or updated since the last sync.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override