HealthDataSyncToken class final

A synchronization token representing a position in the health data stream.

Treat this object as opaque. Persist it to resume sync from this point.

Annotations

Constructors

HealthDataSyncToken.fromJson(Map<String, dynamic> json)
Creates a HealthDataSyncToken from a JSON map.
factory
HealthDataSyncToken.internal({required String token, required List<HealthDataType<HealthRecord, MeasurementUnit>> dataTypes, required DateTime createdAt})
Creates a HealthDataSyncToken instance.
factory

Properties

createdAt DateTime
When this sync token was originally created (UTC).
final
dataTypes List<HealthDataType<HealthRecord, MeasurementUnit>>
Health data types included in this sync token's scope.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Platform-specific opaque token string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this HealthDataSyncToken to a JSON-compatible map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override