HealthRecord class sealed

Base class for all health records.

Acknowledgments

Android Health Connect SDK

Implementation Details:

  • All code in this file is an original Dart implementation written specifically for Flutter
  • No source code has been copied from Health Connect SDK (written in Kotlin/Java)
  • The design follows functional organizational patterns that are industry-standard for health data categorization
  • This is a cross-platform abstraction layer designed for interoperability between Android and iOS health platforms
Available extensions
Annotations

Properties

category HealthDataTypeCategory
The category of this health record, derived from its associated data type.
no setter
dataType HealthDataType<HealthRecord, MeasurementUnit>

Available on HealthRecord, provided by the HealthRecordDataTypeExtension extension

Returns the HealthDataType associated with this HealthRecord.
no setter
hashCode int
Returns a hash code for this health record.
no setteroverride
id HealthRecordId
The unique identifier for this health record.
final
metadata Metadata
Metadata describing the context and origin of this health record.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedHealthPlatforms List<HealthPlatform>
The list of health platforms that support this data.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
Compares this health record to another for equality.
override