MeasurementUnit class sealed

Base abstract class for all measurement units in the health connector.

Acknowledgments

Android Health Connect SDK

Implementation Details:

  • All code in this file is an original Dart implementation written specifically for Flutter
  • No source code has been copied from Health Connect SDK (written in Kotlin/Java)
  • The design follows functional organizational patterns that are industry-standard for health data categorization
  • This is a cross-platform abstraction layer designed for interoperability between Android and iOS health platforms
Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited