PermissionRequestResult class final
Represents the result of a single permission request.
- Annotations
Constructors
- PermissionRequestResult({required Permission permission, required PermissionStatus status})
-
Creates a permission request result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- permission → Permission
-
The permission that was requested.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → PermissionStatus
-
The status of the permission after the request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited