BloodPressureAggregateRequest class final

Request to perform an aggregation query on blood pressure health records.

This specialized request extends AggregateRequest and includes an additional field to store the specific blood pressure data type (systolic or diastolic) being aggregated.

Inheritance
Annotations

Constructors

BloodPressureAggregateRequest({required HealthDataType<HealthRecord, Pressure> dataType, required AggregationMetric aggregationMetric, required DateTime startTime, required DateTime endTime})
Creates a blood pressure aggregation request.

Properties

aggregationMetric AggregationMetric
The type of aggregation to perform.
finalinherited
dataType HealthDataType<HealthRecord, Pressure>
The type of health data to aggregate.
finalinherited
endTime DateTime
Exclusive end of the time range.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
Inclusive start of the time range.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited