ReadRecordsInTimeRangeRequest<R extends HealthRecord> class final

Request to read multiple health records within a time range.

Annotations

Constructors

ReadRecordsInTimeRangeRequest({required HealthDataType<HealthRecord, MeasurementUnit> dataType, required DateTime startTime, required DateTime endTime, int pageSize = HealthConnectorConfigConstants.defaultPageSize, String? pageToken, List<DataOrigin> dataOrigins = const [], @sinceV3_0_0 SortDescriptor sortDescriptor = SortDescriptor.timeDescending})
Creates a request to read health records within a time range.

Properties

dataOrigins List<DataOrigin>
List of data origins to filter by.
final
dataType HealthDataType<HealthRecord, MeasurementUnit>
The type of health data to read.
finalinherited
endTime DateTime
Exclusive end of the time range.
final
hashCode int
The hash code for this object.
no setteroverride
pageSize int
Maximum number of records to return per page.
final
pageToken String?
Opaque pagination token.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortDescriptor SortDescriptor
Descriptor defining how the results should be ordered.
final
startTime DateTime
Inclusive start of the time range.
final

Methods

copyWith({String? pageToken, SortDescriptor? sortDescriptor}) ReadRecordsInTimeRangeRequest<R>
Creates a copy of this request with a new page token.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override