AggregationMetric enum
Defines the type of aggregation to perform on health data.
- Inheritance
- Available extensions
- Annotations
Values
- sum → const AggregationMetric
-
Sum of all values in the time range.
Only meaningful for cumulative data types like steps, distance, or energy burned.
- avg → const AggregationMetric
-
Average (mean) value across all data points.
Meaningful for both cumulative and measurement data types.
- min → const AggregationMetric
-
Minimum value in the dataset.
Useful for finding the lowest recorded value in a time range.
- max → const AggregationMetric
-
Maximum value in the dataset.
Useful for finding the highest recorded value in a time range.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AggregationMetric> - A constant List of the values in this enum, in order of their declaration.