HealthConnectorException class sealed
Sealed exception class for all health connector plugin errors.
- Implemented types
- Annotations
Constructors
- HealthConnectorException.fromCode(HealthConnectorErrorCode code, String message, {Object? cause, StackTrace? stackTrace})
-
Creates a specific HealthConnectorException subclass based on the
provided
code.factory
Properties
- cause → Object?
-
The underlying cause of this exception, if any.
final
- code → HealthConnectorErrorCode
-
The error code identifying the type of error.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String
-
A human-readable description of the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace of this exception, if any.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override