HealthPlatform enum
Represents the available health platform APIs.
- Inheritance
- Available extensions
- Annotations
Values
- appleHealth → const HealthPlatform
-
iOS HealthKit on iOS.
const HealthPlatform(OperatingSystem.iOS) - healthConnect → const HealthPlatform
-
Health Connect on Android.
const HealthPlatform(OperatingSystem.android)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - os → OperatingSystem
-
The operating system this health platform runs on.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HealthPlatform> - A constant List of the values in this enum, in order of their declaration.