UnsupportedOperationException class final
Exception thrown when an API not supported by the current platform or version is used.
See Also
- Inheritance
-
- Object
- HealthConnectorException
- UnsupportedOperationException
- Annotations
Constructors
- UnsupportedOperationException(String message, {Object? cause, StackTrace? stackTrace})
-
Creates an UnsupportedOperationException.
const
Properties
- cause → Object?
-
The underlying cause of this exception, if any.
finalinherited
- code → HealthConnectorErrorCode
-
The error code identifying the type of error.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable description of the error.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace of this exception, if any.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited