ActivityIntensityAggregateRequest class final
Request to perform aggregation on activity intensity health records.
This specialized request extends AggregateRequest and includes an additional field intensityType to specify which activity intensity metric to aggregate.
- Inheritance
-
- Object
- AggregateRequest<
TimeDuration> - ActivityIntensityAggregateRequest
- Annotations
Constructors
-
ActivityIntensityAggregateRequest({required HealthDataType<
HealthRecord, TimeDuration> dataType, required DateTime startTime, required DateTime endTime, ActivityIntensityType? intensityType}) - Creates an activity intensity aggregation request.
Properties
- aggregationMetric → AggregationMetric
-
The type of aggregation to perform.
finalinherited
-
dataType
→ HealthDataType<
HealthRecord, TimeDuration> -
The type of health data to aggregate.
finalinherited
- endTime → DateTime
-
Exclusive end of the time range.
finalinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- intensityType → ActivityIntensityType?
-
The intensity type to aggregate.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → DateTime
-
Inclusive start of the time range.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override