AggregateRequest<U extends MeasurementUnit> class
sealed
Base request class to perform an aggregation query on health records.
- Annotations
Properties
- aggregationMetric → AggregationMetric
-
The type of aggregation to perform.
final
-
dataType
→ HealthDataType<
HealthRecord, U> -
The type of health data to aggregate.
final
- endTime → DateTime
-
Exclusive end of the time range.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → DateTime
-
Inclusive start of the time range.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override