DeleteRecordsByIdsRequest class final
Request to delete specific health records by their IDs.
This request type allows precise deletion of individual records when you have their unique identifiers.
- Inheritance
-
- Object
- DeleteRecordsRequest
- DeleteRecordsByIdsRequest
- Annotations
Constructors
-
DeleteRecordsByIdsRequest({required HealthDataType<
HealthRecord, MeasurementUnit> dataType, required List<HealthRecordId> recordIds}) - Creates a request to delete specific health records by their IDs.
Properties
-
dataType
→ HealthDataType<
HealthRecord, MeasurementUnit> -
The type of health data to delete.
finalinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
-
recordIds
→ List<
HealthRecordId> -
List of unique record identifiers to delete.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override