DeleteRecordsInTimeRangeRequest class final
Request to delete all health records within a time range.
This request type allows deletion of all records of a specific type that fall within the specified time range. This is useful for bulk cleanup operations or removing data from a specific period.
Data Ownership Restriction
Apps can only delete health records that they created. Attempting to delete records created by other apps, manually entered by users, or system-generated will fail with AuthorizationException.
- Inheritance
-
- Object
- DeleteRecordsRequest
- DeleteRecordsInTimeRangeRequest
- Annotations
Constructors
-
DeleteRecordsInTimeRangeRequest({required HealthDataType<
HealthRecord, MeasurementUnit> dataType, required DateTime startTime, required DateTime endTime}) - Creates a request to delete records within a time range.
Properties
-
dataType
→ HealthDataType<
HealthRecord, MeasurementUnit> -
The type of health data to delete.
finalinherited
- endTime → DateTime
-
Inclusive end of the time range.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → DateTime
-
Inclusive start of the time range.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override