DeleteRecordsRequest class sealed
Base sealed class for all delete records requests.
Data Ownership Restriction
Apps can only delete health records that they created. Attempting to delete records created by other apps, manually entered by users, or system-generated will fail with AuthorizationException.
- Annotations
Properties
-
dataType
→ HealthDataType<
HealthRecord, MeasurementUnit> -
The type of health data to delete.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited