ReadRecordByIdRequest<R extends HealthRecord> class
final
Request to read a single health record by its ID.
- Inheritance
-
- Object
- ReadRecordsRequest<
HealthRecord> - ReadRecordByIdRequest
- Annotations
Constructors
-
ReadRecordByIdRequest({required HealthDataType<
HealthRecord, MeasurementUnit> dataType, required HealthRecordId id}) - Creates a request to read a health record by its ID.
Properties
-
dataType
→ HealthDataType<
HealthRecord, MeasurementUnit> -
The type of health data to read.
finalinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → HealthRecordId
-
The unique identifier of the record to read.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override