ReadRecordsInTimeRangeResponse<R extends HealthRecord> class
final
Response from reading multiple health records.
- Annotations
Constructors
-
ReadRecordsInTimeRangeResponse({required List<
R> records, ReadRecordsInTimeRangeRequest<R> ? nextPageRequest}) -
Creates a read records response.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasMorePages → bool
-
Returns true if there are more pages of records to fetch.
no setter
-
nextPageRequest
→ ReadRecordsInTimeRangeRequest<
R> ? -
Request for fetching the next page of records.
final
-
records
→ List<
R> -
The list of health records in this page.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override