StandardAggregateRequest<U extends MeasurementUnit> class
final
Standard aggregate request for standard health data types.
This is the default implementation for most health data types that don't require specialized aggregation handling.
- Inheritance
-
- Object
- AggregateRequest<
U> - StandardAggregateRequest
- Annotations
Constructors
-
StandardAggregateRequest({required HealthDataType<
HealthRecord, U> dataType, required AggregationMetric aggregationMetric, required DateTime startTime, required DateTime endTime}) - Creates a request to aggregate health records.
Properties
- aggregationMetric → AggregationMetric
-
The type of aggregation to perform.
finalinherited
-
dataType
→ HealthDataType<
HealthRecord, U> -
The type of health data to aggregate.
finalinherited
- endTime → DateTime
-
Exclusive end of the time range.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → DateTime
-
Inclusive start of the time range.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited